@@ -18,7 +18,7 @@
 package POE::Component::MessageQueue;
 use Moose;
 
-our $VERSION = '0.2.9';
+our $VERSION = '0.2.10';
 
 use POE 0.38;
 use POE::Component::Server::Stomp;
@@ -517,28 +517,33 @@ POE::Component::MessageQueue - A POE message queue that uses STOMP for its commu
 If you are only interested in running with the recommended storage backend and
 some predetermined defaults, you can use the included command line script:
 
-  POE::Component::MessageQueue version 0.2.9
+  POE::Component::MessageQueue version 0.2.10
   Copyright 2007-2010 David Snopek (http://www.hackyourlife.org)
   Copyright 2007, 2008 Paul Driver <frodwith@gmail.com>
   Copyright 2007 Daisuke Maki <daisuke@endeworks.jp>
-  
+
   mq.pl [--port|-p <num>]               [--hostname|-h <host>]
         [--front-store <str>]           [--front-max <size>] 
         [--granularity <seconds>]       [--nouuids]
         [--timeout|-i <seconds>]        [--throttle|-T <count>]
+		[--dbi-dsn <str>]               [--mq-id <str>]
+		[--dbi-username <str>]          [--dbi-password <str>]
         [--pump-freq|-Q <seconds>]
         [--data-dir <path_to_dir>]      [--log-conf <path_to_file>]
         [--stats-interval|-i <seconds>] [--stats]
         [--pidfile|-p <path_to_file>]   [--background|-b]
         [--crash-cmd <path_to_script>]
         [--debug-shell] [--version|-v]  [--help|-h]
-  
+
   SERVER OPTIONS:
     --port     -p <num>     The port number to listen on (Default: 61613)
     --hostname -h <host>    The hostname of the interface to listen on 
                             (Default: localhost)
-  
+
   STORAGE OPTIONS:
+    --storage <str>         Specify which overall storage engine to use.  This
+                            affects what other options are value.  (can be
+                            default or dbi)
     --front-store -f <str>  Specify which in-memory storage engine to use for
                             the front-store (can be memory or bigmemory).
     --front-max <size>      How much message body the front-store should cache.
@@ -552,29 +557,35 @@ some predetermined defaults, you can use the included command line script:
     --granularity <secs>    How often (in seconds) Complex should check for
                             messages that have passed the timeout.  
     --[no]uuids             Use (or do not use) UUIDs instead of incrementing
-                            integers for message IDs.  Default: uuids 
+                            integers for message IDs.  (Default: uuids)
     --throttle -T <count>   The number of messages that can be stored at once 
                             before throttling (Default: 2)
     --data-dir <path>       The path to the directory to store data 
                             (Default: /var/lib/perl_mq)
     --log-conf <path>       The path to the log configuration file 
-                            (Default: /etc/perl_mq/log.conf
-  
+                            (Default: /etc/perl_mq/log.conf)
+
+    --dbi-dsn <str>         The database DSN when using --storage dbi
+    --dbi-username <str>    The database username when using --storage dbi
+    --dbi-password <str>    The database password when using --storage dbi
+    --mq-id <str>           A string uniquely identifying this MQ when more
+                            than one MQ use the DBI database for storage
+
   STATISTICS OPTIONS:
     --stats                 If specified the, statistics information will be 
                             written to $DATA_DIR/stats.yml
     --stats-interval <secs> Specifies the number of seconds to wait before 
                             dumping statistics (Default: 10)
-  
+
   DAEMON OPTIONS:
     --background -b         If specified the script will daemonize and run in the
                             background
     --pidfile    -p <path>  The path to a file to store the PID of the process
-  
+
     --crash-cmd  <path>     The path to a script to call when crashing.
                             A stacktrace will be printed to the script's STDIN.
                             (ex. 'mail root@localhost')
-  
+
   OTHER OPTIONS:
     --debug-shell           Run with POE::Component::DebugShell
     --version    -v         Show the current version.
@@ -937,11 +948,11 @@ L<POE::Component::MessageQueue::Storage::DBI>
 
 =back
 
-The database format has changed.
+The database format has changed!
 
-B<Note:> When using L<POE::Component::MessageQueue::Storage::Default> (meaning mq.pl)
-the database will be automatically updated in place, so you don't need to worry
-about this.
+B<Note:> When using L<POE::Component::MessageQueue::Storage::Default> (meaning mq.pl
+--storage default) the database will be automatically updated in place, so you don't
+need to worry about this.
 
 Included in the distribution, is a schema/ directory with a few SQL scripts for 
 upgrading:
@@ -959,13 +970,18 @@ the above upgrade script.  This one has a SQLite specific version: upgrade-0.1.8
 
 =item *
 
-upgrade-0.2.3.sql -- Apply if you are upgrading from version 0.2.2 or older or after
-applying the above upgrade script.
+upgrade-0.2.3.sql -- Apply if you are upgrading from version 0.2.2 or older (after
+applying the above upgrade scripts).
 
 =item *
 
 upgrade-0.2.9-mysql.sql -- Doesn't apply to SQLite users!  Apply if you are upgrading from version
-0.2.8 or older or after applying the above upgrade script.
+0.2.8 or older (after applying the above upgrade scripts).
+
+=item *
+
+upgrade-0.2.10-mysql.sql -- Doesn't apply to SQLite users!  Apply if you are upgrading from version
+0.2.9 or older (after applying the above upgrade scripts).
 
 =back
 
@@ -998,9 +1014,6 @@ The goal of this module is not to support every possible feature but rather to
 be small, simple, efficient and robust.  For the most part expect incremental
 changes to address those areas.
 
-There is one remaining big feature coming soon and that is the ability to run
-PoCo::MQ clustered accross multiple servers with some kind of fail-over.
-
 Beyond that we have a TODO list (shown below) called B<"The Long Road To
 1.0">.  This is a list of things we feel we need to have inorder to call the
 product complete.  That includes management and monitoring tools for sysadmins
